Products.zms._confmanager.ConfManager

Package Products :: Package zms :: Module _confmanager :: Class ConfManager |
[frames] | no frames]

# Class ConfManager

    _multilangmanager.MultiLanguageManager --+
                                             |
              _filtermanager.FilterManager --+
                                             |
                                            ConfManager

Instance Methods
importConfPackage(self, file, createIfNotExists=0) |
getConfXmlFile(self, file) |
importConf(self, file, createIfNotExists=0, syncIfNecessary=True) |
getPluginIds(self, path=[]) |
getConfFiles(self, remote=True, pattern=None, REQUEST=None, RESPONSE=None) ConfManager.getConfFiles |
getSequence(self) |
getMediaDb(self) |
getThemes(self) |
getResourceFolders(self) |
getStylesheet(self, id=None) |
getStylesheets(self) |
customize_manage_options(self) |
getConfManager(self) |
get_conf_properties(self) |
getConfPropertiesDefaults(self) |
getConfProperties(self, prefix=None, inherited=False, REQUEST=None) ConfManager.getConfProperties |
delConfProperty(self, key) |
getReqProperty(self, key, default=None, REQUEST=None) ConfManager.getReqProperty |
get_conf_property(self, *args, **kwargs) |
getConfProperty(self, key, default=None, REQUEST=None) ConfManager.getConfProperty |
setConfProperty(self, key, value) |
manage_customizeSystem(self, btn, key, lang, REQUEST, RESPONSE=None) ConfManager.manage_customizeSystem |
manage_customizeDesign(self, btn, lang, REQUEST, RESPONSE) ConfManager.manage_customizeDesign |
getWfActivities(self) |
getWfActivitiesIds(self) |
getWfActivity(self, id) |
getWfTransitions(self) |
getWfTransition(self, id) |
getMetaobjManager(self) |
getMetaobjRevision(self, id) |
getMetaobjId(self, name) |
getMetaobjIds(self, sort=False, excl_ids=[]) |
getMetaobj(self, id) |
getMetaobjAttrIds(self, meta_id, types=[]) |
getMetaobjAttrs(self, meta_id, types=[]) |
getMetaobjAttr(self, id, attr_id, sync=True) |
getMetaobjAttrIdentifierId(self, meta_id) |
notifyMetaobjAttrAboutValue(self, meta_id, key, value) |
getMetacmdManager(self) |
getMetaCmdDescription(self, id) getMetaCmdDescription |
getMetaCmd(self, id) |
getMetaCmdIds(self, sort=1) |
getMetaCmds(self, context=None, stereotype='', sort=True) |
getRepositoryManager(self) |
getWorkflowManager(self) |
getFormatManager(self) |
getTextFormatDefault(self) |
getTextFormat(self, id, REQUEST) |
getTextFormats(self, REQUEST) |
getCharFormats(self) |
getCatalogAdapter(self) |
getLocale(self) |

Class Variables
| security = `ClassSecurityInfo()`
| manage_customize = `PageTemplateFile('zpt/ZMS/manage_customize'`...``
| manage_customizeLanguagesForm = `PageTemplateFile('zpt/ZMS/mana`...``
| manage_customizeFilterForm = `PageTemplateFile('zpt/ZMS/manage_`...``
| manage_customizeDesignForm = `PageTemplateFile('zpt/ZMS/manage_`...``
| customize_manage_options__roles__ = `None`

Instance Variables
| __attr_conf_dict__ ############################################################################ ### ### Configuration-System ### ############################################################################

Class Variable Details

  ### manage_customize Value:
      PageTemplateFile('zpt/ZMS/manage_customize', globals())

  ### manage_customizeLanguagesForm Value:
      PageTemplateFile('zpt/ZMS/manage_customizelanguagesform', globals())

  ### manage_customizeFilterForm Value:
      PageTemplateFile('zpt/ZMS/manage_customizefilterform', globals())

  ### manage_customizeDesignForm Value:
      PageTemplateFile('zpt/ZMS/manage_customizedesignform', globals())